@@ -50,7 +50,7 @@ class AnyscaleAWSNodeProvider(AWSNodeProvider):  # type: ignore
     ) -> Any:
         aws_instance_dict = super().create_node(node_config, tags, count)
         instance_dict = {}
-        for instance_id in aws_instance_dict.keys():
+        for instance_id in aws_instance_dict:
             instance_dict[instance_id] = {
                 "PublicIpAddress": aws_instance_dict[instance_id].public_ip_address
             }
@@ -92,8 +92,8 @@ class AnyscaleAWSNodeProvider(AWSNodeProvider):  # type: ignore
         node_tags[TAG_ANYSCALE_HOST] = shared_anyscale_conf.ANYSCALE_HOST
 
         for k, v in node_tags.items():
-            m = "Set tag {}={} on {}".format(k, v, node_id)
-            with LogTimer("AWSNodeProvider: {}".format(m)):
+            m = f"Set tag {k}={v} on {node_id}"
+            with LogTimer(f"AWSNodeProvider: {m}"):
                 if k == TAG_RAY_NODE_NAME:
                     k = "Name"
                 self.ec2.meta.client.create_tags(
