@@ -150,7 +150,7 @@ class AnyscaleInstanceManagerNodeProvider(NodeProvider):
     @staticmethod
     def bootstrap_config(cluster_config: Dict[str, Any]) -> Dict[str, Any]:
         cluster_config = copy.deepcopy(cluster_config)
-        inner_provider_cls = AnyscalePoolingNodeProvider._get_inner_provider_class_from_config(
+        inner_provider_cls = AnyscalePoolingNodeProvider._get_inner_provider_class_from_config(  # noqa: SLF001
             cluster_config
         )
         primary_provider = cluster_config["provider"]
@@ -167,7 +167,7 @@ class AnyscaleInstanceManagerNodeProvider(NodeProvider):
         cluster_config: Dict[str, Any]
     ) -> Dict[str, Any]:
         cluster_config = copy.deepcopy(cluster_config)
-        inner_provider_cls = AnyscalePoolingNodeProvider._get_inner_provider_class_from_config(
+        inner_provider_cls = AnyscalePoolingNodeProvider._get_inner_provider_class_from_config(  # noqa: SLF001
             cluster_config
         )
 
