@@ -8,6 +8,9 @@ import colorama  # type: ignore
 from halo import Halo
 
 
+_process_start_time = time.time()
+
+
 class BlockLogger:
     """
     Logger class for the CLI. Supports formatting in blocks if `block_label` is provided to
@@ -15,8 +18,10 @@ class BlockLogger:
     provided.
     """
 
-    def __init__(self, log_output: bool = True) -> None:
-        self.t0 = time.time()
+    def __init__(
+        self, log_output: bool = True, t0: float = _process_start_time,
+    ) -> None:
+        self.t0 = t0
         # Flag to disable all terminal output from CLILogger (useful for SDK)
         self.log_output = log_output
         self.current_block: Optional[str] = None
@@ -132,10 +137,10 @@ class BlockLogger:
             delta -= 60
         output = ""
         if hours:
-            output += "{}h".format(hours)
+            output += f"{hours}h"
         if minutes:
-            output += "{}m".format(minutes)
-        output += "{}s".format(round(delta, 1))
+            output += f"{minutes}m"
+        output += f"{round(delta, 1)}s"
         return output
 
     def error(self, *msg: str) -> None:
@@ -159,11 +164,24 @@ class LogsLogger(BlockLogger):
     def log(self, msg: str):
         print(msg)
 
+    def is_interactive_cli_enabled(self) -> bool:
+        """Check if shell is interactive
+        """
+
+        default_env_var = "1" if sys.stderr.isatty() else "0"
+        return os.environ.get("ANYSCALE_CLI_INTERACTIVE_UX", default_env_var) == "1"
+
     @contextmanager
     def spinner(self, msg: str):
         """ Create a spinner with the starting text.
         To update the text next to the spinner, set `spinner.text = "new_text"`
         The spinner will be stopped when the context is exited.
+        Spinner is only enabled for interactive shell
         """
-        with Halo(text=msg, spinner="dots", stream=sys.stderr) as spinner:
+
+        enable_spinner = self.is_interactive_cli_enabled()
+
+        with Halo(
+            text=msg, spinner="dots", stream=sys.stderr, enabled=enable_spinner
+        ) as spinner:
             yield spinner
