@@ -2,10 +2,14 @@ from typing import List, Optional
 
 import click
 
+from anyscale.cli_logger import BlockLogger
 from anyscale.commands.util import OptionPromptNull
 from anyscale.controllers.cloud_controller import CloudController
 
 
+log = BlockLogger()  # CLI Logger
+
+
 @click.group(
     "cloud",
     short_help="Configure cloud provider authentication for Anyscale.",
@@ -120,10 +124,9 @@ def cloud_set_default(
     "--anyscale-managed",
     is_flag=True,
     default=False,
-    hidden=True,
     help="Let anyscale create all the resources.",
 )
-def setup_cloud(
+def setup_cloud(  # noqa: PLR0913
     provider: str,
     region: str,
     name: str,
@@ -250,7 +253,7 @@ def cloud_config_get(
 
 @cloud_cli.command(
     name="secrets",
-    help="Allow clusters started in this cloud to access secrets manager.",
+    help="[Deprecated] Allow clusters started in this cloud to access secrets manager.",
     hidden=True,
 )
 @click.argument("cloud-name", required=False)
@@ -282,6 +285,11 @@ def cloud_secrets(
     write_permissions: bool,
     yes: bool,
 ) -> None:
+    log.warning(
+        "`anyscale cloud secrets` has been deprecated. Please instead use the cloud provider "
+        "API to add the appropriate policies to access the secrets manager to your "
+        "dataplane IAM role. We will remove this command at the end of Q1 2023."
+    )
     if cloud_name and name and cloud_name != name:
         raise click.ClickException(
             "The positional argument CLOUD_NAME and the keyword argument --name "
@@ -352,7 +360,7 @@ def cloud_secrets(
 @click.option(
     "--private-network", help="Use private network.", is_flag=True, default=False,
 )
-def register_cloud(
+def register_cloud(  # noqa: PLR0913
     provider: str,
     region: str,
     name: str,
