@@ -102,8 +102,8 @@ def log_cli() -> None:
 @option_download_dir
 @option_ttl
 @option_parallelism
-def anyscale_logs_cluster(
-    id: str,
+def anyscale_logs_cluster(  # noqa: PLR0913
+    id: str,  # noqa: A002
     download: bool,
     tail: int,
     # filters
@@ -128,7 +128,7 @@ def anyscale_logs_cluster(
     elif head_only:
         node_type = NodeType.HEAD_NODE
 
-    filter = LogFilter(
+    filter = LogFilter(  # noqa: A001
         cluster_id=id,
         glob=glob,
         node_ip=node_ip,
@@ -150,7 +150,7 @@ def anyscale_logs_cluster(
     else:
         # This is for both tailing logs AND for the default behavior (no -t/-d/-f => rendering them in UI).
         console = Console()
-        log_group = logs_controller.get_logs_for_tail(
+        log_group = logs_controller.get_log_group(
             filter=filter,
             page_size=DEFAULT_PAGE_SIZE,
             timeout=timedelta(seconds=DEFAULT_TIMEOUT),
@@ -221,4 +221,4 @@ def convert_size(size_bytes):
     i = int(math.floor(math.log(size_bytes, 1024)))
     p = math.pow(1024, i)
     s = round(size_bytes / p, 2)
-    return "%s %s" % (s, size_name[i])
+    return f"{s} {size_name[i]}"
