@@ -49,6 +49,37 @@ def deploy(
     )
 
 
+@service_cli.command(
+    name="rollout",
+    help="Rollout a Service v2 to Anyscale. Please contact support for details.",
+)
+@click.option(
+    "-f",
+    "--service_config_file",
+    required=True,
+    help="The path of the service configuration file.",
+)
+@click.option("--name", "-n", required=False, default=None, help="Name of service.")
+@click.option("--version", required=False, default=None, help="Version of service.")
+@click.option(
+    "--canary-percent",
+    required=False,
+    default=None,
+    type=int,
+    help="The percentage of traffic going to the new version of Service that you are deploying",
+)
+def rollout(
+    service_config_file: str,
+    name: Optional[str],
+    version: Optional[str],
+    canary_percent: Optional[int],
+) -> None:
+    service_controller = ServiceController()
+    service_controller.rollout(
+        service_config_file, name=name, version=version, canary_percent=canary_percent
+    )
+
+
 @service_cli.command(name="list", help="Display information about existing services.")
 @click.option(
     "--name", "-n", required=False, default=None, help="Filter by service name."
@@ -82,7 +113,7 @@ def deploy(
     help="Max items to show in list.",
     callback=validate_non_negative_arg,
 )
-def list(
+def list(  # noqa: A001, PLR0913
     name: Optional[str],
     service_id: Optional[str],
     project_id: Optional[str],
@@ -109,6 +140,18 @@ def archive(service_id: Optional[str], name: Optional[str]) -> None:
     service_controller.archive(service_id=service_id, service_name=name)
 
 
+@service_cli.command(
+    name="rollback", help="Attempt to rollback a service asynchronously."
+)
+@click.option("--service-id", "--id", required=True, help="Id of service.")
+def rollback(service_id: str) -> None:
+    # TODO (kamenshah)
+    # Add service_name and service_config_file as arguments
+    # If service_id is None then derive id from service_name or service_config_file
+    service_controller = ServiceController()
+    service_controller.rollback(service_id=service_id,)
+
+
 @service_cli.command(
     name="terminate", help="Attempt to terminate a service asynchronously."
 )
