@@ -1323,7 +1323,7 @@ class ClientBuilder:
             )
         finally:
             os.chdir(cur_dir)
-        self._os._exit(0)  # pylint:disable=private-use
+        self._os._exit(0)  # pylint:disable=private-use  # noqa: SLF001
 
     def _exec_self_in_local_docker(self) -> None:
         """Run the current main file in a local docker image."""
@@ -1349,7 +1349,7 @@ class ClientBuilder:
         ]
         self._log.debug("Running", command)
         self._subprocess.check_call(command)
-        self._os._exit(0)  # pylint:disable=private-use
+        self._os._exit(0)  # pylint:disable=private-use  # noqa: SLF001
 
 
 # This implements the following utility function for users:
