@@ -1106,6 +1106,12 @@ class CloudController(BaseController):
                 create_cloud_resource = associate_subnets_with_azs(
                     create_cloud_resource, region
                 )
+                # We are only taking the first security group in the list for now
+                # We also only verify the first security group and warn about multiple security groups in verify_aws_security_groups
+                create_cloud_resource.aws_security_groups = [
+                    create_cloud_resource.aws_security_groups[0]
+                ]
+
                 # update cloud with verified cloud resources
                 self.api_client.update_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_put(
                     cloud_id=cloud_id,
