@@ -132,8 +132,11 @@ class ClusterComputeController(BaseController):
     """
 
     def __init__(
-        self, log: BlockLogger = BlockLogger(), initialize_auth_api_client: bool = True
+        self, log: Optional[BlockLogger] = None, initialize_auth_api_client: bool = True
     ):
+        if log is None:
+            log = BlockLogger()
+
         super().__init__(initialize_auth_api_client=initialize_auth_api_client)
         self.log = log
         self.log.open_block("Output")
@@ -149,7 +152,7 @@ class ClusterComputeController(BaseController):
             cluster_compute: Dict[str, Any] = yaml.load(
                 cluster_compute_file, Loader=SafeLoader
             )
-        except Exception as e:
+        except Exception as e:  # noqa: BLE001
             raise ClickException(f"Could not load cluster compute file: {e}")
 
         cluster_compute_config_model = CreateClusterComputeConfigModel(
@@ -168,7 +171,7 @@ class ClusterComputeController(BaseController):
             idle_termination_minutes=cluster_compute_config_model.idle_termination_minutes,
         )
         if name is None:
-            name = "cli-config-{}".format(datetime.now().isoformat())
+            name = f"cli-config-{datetime.now().isoformat()}"
         cluster_compute_response = self.anyscale_api_client.create_cluster_compute(
             CreateClusterCompute(name=name, config=cluster_compute_config)
         )
@@ -180,7 +183,9 @@ class ClusterComputeController(BaseController):
         log.info(f"Cluster compute id: {cluster_compute_id}")
         log.info(f"Cluster compute name: {cluster_compute_name}")
 
-    def delete(self, cluster_compute_name: Optional[str], id: Optional[str]) -> None:
+    def delete(
+        self, cluster_compute_name: Optional[str], id: Optional[str]  # noqa: A002
+    ) -> None:
         """
         TODO: shawnp. Remove once archive functionality is enabled on prod.
         Deletes the cluster compute with the given name or id.
