@@ -1,3 +1,4 @@
+import contextlib
 import json
 import os
 from typing import Optional
@@ -34,8 +35,11 @@ COMPUTE_CONFIG_FILENAME = "example_compute_config.json"
 
 class ProjectController(BaseController):
     def __init__(
-        self, log: BlockLogger = BlockLogger(), initialize_auth_api_client: bool = True
+        self, log: Optional[BlockLogger] = None, initialize_auth_api_client: bool = True
     ):
+        if log is None:
+            log = BlockLogger()
+
         super().__init__(initialize_auth_api_client=initialize_auth_api_client)
 
         self.log = log
@@ -63,13 +67,11 @@ class ProjectController(BaseController):
         Call API to create a new project given a project name.
         """
         existing_projects = []
-        try:
+        with contextlib.suppress(click.ClickException, ApiException):
             user_info = self.api_client.get_user_info_api_v2_userinfo_get()
             existing_projects = self.api_client.find_project_by_project_name_api_v2_projects_find_by_name_get(
                 name, owner=user_info.result.username
             ).results
-        except (click.ClickException, ApiException):
-            pass
 
         if len(existing_projects):
             project_id = existing_projects[0].id
@@ -98,7 +100,7 @@ class ProjectController(BaseController):
         project_id: Optional[str],
         name: Optional[str],
         config: Optional[str] = None,
-        requirements: Optional[str] = None,
+        requirements: Optional[str] = None,  # noqa: ARG002
     ) -> None:
         if config:
             message = (
@@ -128,7 +130,7 @@ class ProjectController(BaseController):
                     resp = self.api_client.get_project_api_v2_projects_project_id_get(
                         project_id
                     )
-                except Exception:
+                except Exception:  # noqa: BLE001
                     resp = None
                 if resp and resp.result.id == project_id:
                     if name != resp.result.name:
@@ -180,14 +182,11 @@ class ProjectController(BaseController):
         if organization.default_cloud_id:
             # Use default cloud id if organization has one and if user has correct
             # permissions for it.
-            try:
+            with contextlib.suppress(Exception):
                 get_cloud_id_and_name(
                     self.api_client, cloud_id=organization.default_cloud_id
                 )
                 cloud_id = organization.default_cloud_id
-            except Exception:
-                # Fallback to other options for getting cloud id.
-                pass
         if not cloud_id and project_id:
             # See if the project has a cloud ID for us to use.
             project = self.anyscale_api_client.get_project(project_id).result
