@@ -62,7 +62,7 @@ def load_yaml_file_as_dict(config_file: str) -> Dict[str, Any]:
     if not os.path.exists(config_file):
         raise click.ClickException(f"Config file {config_file} not found.")
 
-    with open(config_file, "r") as f:
+    with open(config_file) as f:
         config_dict = yaml.safe_load(f)
     return config_dict
 
@@ -90,9 +90,11 @@ def get_local_timezone() -> str:
 
 class ScheduleController(BaseController):
     def __init__(
-        self,
-        log: LogsLogger = LogsLogger(),  # The default logger is shared across instances of this class.
+        self, log: Optional[LogsLogger] = None,
     ):
+        if log is None:
+            log = LogsLogger()
+
         super().__init__()
         self.log = log
         self.log.open_block("Output")
@@ -108,7 +110,7 @@ class ScheduleController(BaseController):
         schedule_config = self._resolve_config(
             schedule_config_file, name=name, description=description
         )
-        id = self.schedule_api.apply(schedule_config)
+        id = self.schedule_api.apply(schedule_config)  # noqa: A001
         self.url(id)
         self.log.info(f"Schedule {id} has been updated successfully.")
         return id
@@ -131,7 +133,7 @@ class ScheduleController(BaseController):
         self,
         *,
         schedule_config_file: Optional[str] = None,
-        id: Optional[str] = None,
+        id: Optional[str] = None,  # noqa: A002
         name: Optional[str] = None,
     ) -> str:
         """Try to resolve a Schedule Config File, Name, or Id to a Schedule Id
@@ -158,7 +160,7 @@ class ScheduleController(BaseController):
             try:
                 result = self.schedule_api.get(id)
                 return result.id
-            except Exception as e:
+            except Exception as e:  # noqa: BLE001
                 raise click.ClickException(f"No schedule found with id `{id}`") from e
         elif name:
             schedules = self.schedule_api.list(name=name)
@@ -198,7 +200,7 @@ class ScheduleController(BaseController):
             "Please specify a file, a name, or an id to resolve your schedule"
         )
 
-    def list(self, project_id=None, name=None, creator_id=None, id=None):
+    def list(self, project_id=None, name=None, creator_id=None, id=None):  # noqa: A002
         if id:
             if any([project_id, name, creator_id]):
                 raise click.ClickException(
@@ -211,7 +213,7 @@ class ScheduleController(BaseController):
             )
         print(SchedulesTable(schedules))
 
-    def pause(self, id, is_paused=True):
+    def pause(self, id, is_paused=True):  # noqa: A002
         schedule = self.schedule_api.pause(id, is_paused)
         text = "paused" if is_paused else "resumed"
         self.url(id)
@@ -219,14 +221,14 @@ class ScheduleController(BaseController):
         if not is_paused:
             self.log.info(f"Next trigger at {schedule.next_trigger_at}")
 
-    def trigger(self, id):
+    def trigger(self, id):  # noqa: A002
         created_job = self.schedule_api.trigger(id)
         self.url(id)
         self.log.info(f"Successfully created Job with id {created_job.id}")
         url = self.endpoint_formatter.get_job_endpoint(created_job.id)
         self.log.info(f"View your Production Job at {url}.")
 
-    def url(self, id) -> str:
+    def url(self, id) -> str:  # noqa: A002
         url = self.endpoint_formatter.get_schedule_endpoint(id)
         self.log.info(f"View your schedule at {url}.")
         return url
@@ -248,7 +250,7 @@ class ScheduleApi:
             project_id=project_id, creator_id=creator_id, name=name
         ).results
 
-    def get(self, id: str) -> Any:
+    def get(self, id: str) -> Any:  # noqa: A002
         return self.api_client.get_cron_job_api_v2_experimental_cron_jobs_cron_job_id_get(
             id
         ).result
