@@ -8,7 +8,7 @@ import pytest
 from anyscale.connect_utils.project import ProjectBlock
 
 
-@pytest.fixture
+@pytest.fixture()
 def mock_project_block():
     with patch.multiple(
         "anyscale.connect_utils.project.ProjectBlock", __init__=Mock(return_value=None)
@@ -67,12 +67,9 @@ def test_ensure_project_setup_at_dir_config_exists(mock_project_block):
 
     # Case where .anyscale.yaml exists but doesn't have project_id in the file
     with patch.multiple("os.path", exists=Mock(return_value=True)), patch.multiple(
-        "anyscale.project", get_project_id=Mock(return_value=None)
-    ), patch("builtins.open", mock_open_factory()):
-        with pytest.raises(click.ClickException):
-            assert mock_project_block._ensure_project_setup_at_dir(
-                "mock_project_dir", None
-            )
+        "anyscale.project", get_project_id=Mock(return_value=None),
+    ), patch("builtins.open", mock_open_factory()), pytest.raises(click.ClickException):
+        assert mock_project_block._ensure_project_setup_at_dir("mock_project_dir", None)
 
 
 @pytest.mark.parametrize("project_id", [None, "project_id"])
