@@ -96,11 +96,11 @@ def test_convert_compute_config_aws(mock_auth_api_client) -> None:
                     "min_workers": None,
                     "max_workers": None,
                     "use_spot": False,
-                    "resources": None,
                     "aws_advanced_configurations": None,
                     "gcp_advanced_configurations": None,
                     "aws_advanced_configurations_json": None,
                     "gcp_advanced_configurations_json": None,
+                    "fallback_to_ondemand": False,
                 },
                 {
                     "name": "worker-node-1",
@@ -109,11 +109,11 @@ def test_convert_compute_config_aws(mock_auth_api_client) -> None:
                     "min_workers": None,
                     "max_workers": None,
                     "use_spot": False,
-                    "resources": None,
                     "aws_advanced_configurations": None,
                     "gcp_advanced_configurations": None,
                     "aws_advanced_configurations_json": None,
                     "gcp_advanced_configurations_json": None,
+                    "fallback_to_ondemand": False,
                 },
             ],
             aws={"TagSpecifications": "fake", "IamInstanceProfile": "fake2"},
@@ -316,14 +316,14 @@ def test_convert_cluster_env(mock_auth_api_client) -> None:
 
 
 @pytest.mark.parametrize(
-    "python_version,ray_version,ml,gpu,expected_image",
+    ("python_version", "ray_version", "ml", "gpu", "expected_image"),
     [
         ("3.7", "1.7.0", False, False, "anyscale/ray:1.7.0-py37"),
         ("3.8", "1.7.0", True, False, "anyscale/ray-ml:1.7.0-py38"),
         ("3.7", "2.0.0dev0", False, True, "anyscale/ray:1.7.0-py37-gpu"),
     ],
 )
-def test_select_base_image(
+def test_select_base_image(  # noqa: PLR0913
     python_version: str,
     ray_version: str,
     ml: bool,
@@ -350,7 +350,7 @@ def test_select_base_image(
 
 
 @pytest.mark.parametrize(
-    "python_version,ray_version,ml,gpu,expected_result",
+    ("python_version", "ray_version", "ml", "gpu", "expected_result"),
     [
         ("3.7", "1.7.0", False, False, "ANYSCALE_RAY_1_7_0_PY37"),
         ("3.7", "1.7.1", True, True, "ANYSCALE_RAY_ML_1_7_1_PY37_GPU"),
@@ -358,7 +358,7 @@ def test_select_base_image(
         ("3.8", "1.9.2", False, False, "ANYSCALE_RAY_1_9_2_PY38"),
     ],
 )
-def test_find_enum_name(
+def test_find_enum_name(  # noqa: PLR0913
     python_version: str,
     ray_version: str,
     ml: bool,
