@@ -35,7 +35,7 @@ RAY_COMMIT = "7916500c43de46721c51e6b95fb51cfa2c6078ba"
 def _make_session(i: int, state: str, cloud_id: str = None) -> Session:
     sess = Session(
         id="session_id",
-        name="cluster-{}".format(i),
+        name=f"cluster-{i}",
         created_at=datetime.now(),
         ray_dashboard_url="https://fake_dashboard.com",
         snapshots_history=[],
@@ -47,12 +47,12 @@ def _make_session(i: int, state: str, cloud_id: str = None) -> Session:
         service_proxy_url="http://session-{}.userdata.com/auth?token=value&bar".format(
             i
         ),
-        connect_url="session-{}.userdata.com:8081?port=10001".format(i),
+        connect_url=f"session-{i}.userdata.com:8081?port=10001",
         jupyter_notebook_url="http://session-{}.userdata.com/jupyter/lab?token=value".format(
             i
         ),
         access_token="value",
-        host_name="https://session-{}.userdata.com".format(i),
+        host_name=f"https://session-{i}.userdata.com",
     )
     sess.build_id = "build_id"
     sess.compute_template_id = "mock_compute_template_id"
@@ -88,7 +88,7 @@ def _make_build() -> Build:
 
 def _make_compute_template_config() -> ComputeTemplateConfig:
 
-    return ComputeTemplateConfig(
+    return ComputeTemplateConfig(  # noqa: PIE804
         **{
             "cloud_id": "fake-cloud-id",
             "region": "fake-region",
@@ -190,7 +190,7 @@ def mock_get_start_interactive_session_block():
         yield mock_get_start_interactive_session_block
 
 
-def _make_test_builder(
+def _make_test_builder(  # noqa: PLR0915
     tmp_path: Path,
     session_states: Optional[List[str]] = None,
     setup_project_dir: bool = True,
@@ -275,13 +275,11 @@ def _make_test_builder(
         ]
         sdk.list_sessions.return_value = sess_resp
 
-    setattr(builder, "_start_session", Mock())
+    builder._start_session = Mock()  # type: ignore
     builder._start_session.side_effect = create_session  # type: ignore
     builder._register_compute_template = Mock(return_value="mock_compute_template_id")  # type: ignore
 
-    setattr(
-        builder, "_get_last_used_cloud", Mock(return_value="anyscale_default_cloud")
-    )
+    builder._get_last_used_cloud = Mock(return_value="anyscale_default_cloud")  # type: ignore
 
     if create_build:
         _make_app_template()
@@ -786,12 +784,12 @@ def test_disable_cloud_change(tmp_path: Path, project_test_data: Project) -> Non
     )
     sdk.create_project.return_value = ProjectResponse(result=project_test_data)
     ray.util.disconnect()
-    with pytest.raises(Exception):
+    with pytest.raises(Exception):  # noqa: PT011
         builder.session("cluster-0", update=True).cloud("test_cloud_2").connect()
 
 
 @pytest.mark.parametrize("enable_multiple_clients", [True, False])
-def test_multiple_clients(
+def test_multiple_clients(  # noqa: PLR0913
     enable_multiple_clients: bool,
     tmp_path: Path,
     mock_auth_api_client,
@@ -829,7 +827,7 @@ def test_multiple_clients(
         del os.environ["ANYSCALE_ALLOW_MULTIPLE_CLIENTS"]
 
 
-class MockPopen(object):
+class MockPopen:
     def __init__(self) -> None:
         self.returncode = 0
 
@@ -958,8 +956,8 @@ def test_namespace(mock_auth_api_client) -> None:
 @pytest.mark.parametrize("field", ["pip", "conda"])
 @pytest.mark.parametrize("type", ["python_object", "file"])
 @pytest.mark.parametrize("ray_version", ["1.9.2", "1.10.0", "1.13.0"])
-def test_pin_protobuf_in_runtime_env_if_needed(
-    type, field, ray_version, monkeypatch, tmp_path, mock_auth_api_client
+def test_pin_protobuf_in_runtime_env_if_needed(  # noqa: PLR0913
+    type, field, ray_version, monkeypatch, tmp_path, mock_auth_api_client  # noqa: A002
 ):
     """Test that protobuf is correctly pinned for old Ray versions.
 
@@ -969,7 +967,7 @@ def test_pin_protobuf_in_runtime_env_if_needed(
     if type == "file":
         if field == "pip":
             file = tmp_path / "requirements.txt"
-            file.write_text("requests" + "\n")
+            file.write_text("requests\n")
             runtime_env = {"pip": str(file)}
         elif field == "conda":
             file = tmp_path / "environment.yaml"
@@ -1219,7 +1217,7 @@ def test_multiclient_context() -> None:
 
     # Simulates ClientContext.__init__ after changes from
     # https://github.com/ray-project/ray/pull/17942
-    def multiclient_init(
+    def multiclient_init(  # noqa: PLR0913
         self,
         dashboard_url,
         python_version,
@@ -1246,7 +1244,7 @@ def test_multiclient_context() -> None:
 
     # Simulates ClientContext.__init__ from before changes from
     # https://github.com/ray-project/ray/pull/17942
-    def no_multiclient_init(
+    def no_multiclient_init(  # noqa: PLR0913
         self,
         dashboard_url,
         python_version,
